#
# Copyright (c) 2013 Dorian Pula <dorian.pula@amber-penguin-software.ca>
#
# Rookeries is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# Rookeries is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with Rookeries.  If not, see <http://www.gnu.org/licenses/>.
#
# Please share and enjoy!
#

"""
Main package for Rookeries.

:copyright: Copyright 2013, Dorian Pula <dorian.pula@amber-penguin-software.ca>
:license: AGPL v3+
"""

from flask.ext import assets

from rookeries import config, main, webapp
from rookeries.core import database

__author__ = 'Dorian Pula'
__version__ = '0.4.9'


def make_rookeries_app():
    """Creates and setups a Rookeries webapp."""
    web_app = webapp.make_json_app(__name__)
    web_app.register_blueprint(main.rookeries_app)
    database.db.init_app(web_app)
    config.configure_web_app(web_app)
    register_asset_bundles_with_app(web_app)
    return web_app


def register_asset_bundles_with_app(web_app):
    asset_env = assets.Environment(web_app)
    bundled_css = assets.Bundle(
        'css/*.less',
        filters='less',
        output='css/rookeries-bundle.css'
    )

    bundled_js = assets.Bundle(
        '../../node_modules/rookeries/dist/rookeries.js',
        output='scripts/rookeries-bundle.js',
    )

    # TODO - Figure out nicer way to bundle normally remote assets with option to use CDNs for production.
    openfonts_base_uri = 'http://openfontlibrary.org/face/'
    remote_webfonts = assets.Bundle(
        openfonts_base_uri + 'lavoir',
        openfonts_base_uri + 'benveno',
        openfonts_base_uri + 'consolamono',
    )

    remote_css = assets.Bundle(
        'https://maxcdn.bootstrapcdn.com/font-awesome/4.3.0/css/font-awesome.min.css',
        'https://maxcdn.bootstrapcdn.com/bootstrap/3.3.4/css/bootstrap.min.css',
    )

    asset_env.register('bundled_css', bundled_css)
    asset_env.register('bundled_js', bundled_js)
    asset_env.register('vendor_css', remote_css)
    asset_env.register('vendor_webfonts', remote_webfonts)
