#
# Copyright (c) 2013 Dorian Pula <dorian.pula@amber-penguin-software.ca>
#
# Rookeries is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# Rookeries is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with Rookeries.  If not, see <http://www.gnu.org/licenses/>.
#
# Please share and enjoy!
#

"""
Configuration for Rookeri.es

:copyright: Copyright 2013, Dorian Pula <dorian.pula@amber-penguin-software.ca>
:license: AGPL v3+
"""


from flask_appconfig import env

ROOKERIES_ENV_CONFIG_PREFIX = 'ROOKERIES_'


class DefaultConfig(object):
    """Default configuration for Rookeries."""

    ENVIRONMENTAL_NAME = 'default'
    DEBUG = True
    TESTING = False

    # Database connection configuration for flask-sqlalchemy
    SQLALCHEMY_DATABASE_URI = 'sqlite://'

    # Security configuration - Make sure you change this!
    # Used by Flask for session secrets.
    SECRET_KEY = 'secret-key'
    # Used as a salt for user password hashes
    PASSWORD_SALT = 'password-salt'

    # Mail configuration for the Flask-Mail extension.
    MAIL_SERVER = 'localhost'
    MAIL_PORT = 25
    MAIL_DEFAULT_SENDER = 'user@mail-service.net'


def configure_web_app(web_app):
    """Configure the app first by its default than by a known filename and than an environment variable."""
    web_app.config.from_object(DefaultConfig)
    env.from_envvars(conf=web_app.config, prefix=ROOKERIES_ENV_CONFIG_PREFIX, as_json=False)
