#
# Copyright (c) 2013 Dorian Pula <dorian.pula@amber-penguin-software.ca>
#
# Rookeries is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# Rookeries is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with Rookeries.  If not, see <http://www.gnu.org/licenses/>.
#
# Please share and enjoy!
#

"""
Models for the journal or CMS component.

:copyright: Copyright 2013, Dorian Pula <dorian.pula@amber-penguin-software.ca>
:license: AGPL v3+
"""

import re
from datetime import datetime


class ContentItem(object):
    """Content item for describing various kinds of content."""

    content_id = -1
    content_type = 'blog'
    title = 'Untitled'
    content_body = 'Write me.'
    posted_date = datetime.now()

    supported_content_types = ['article', 'blog', 'comment']

    def __init__(self, id=None, content_type=None, title=None, content_body=None, posted_date=None):
        self.content_id = id
        self.title = title
        self.content_body = content_body
        self.posted_date = posted_date

        self.content_type = content_type
        if content_type not in ContentItem.supported_content_types:
            self.content_type = 'blog'

    def build_nav_url(self, nav_url):
        """Build the navigation URL for a content item by removing improper letters."""

        nav_url = str.lower(nav_url).strip()

        nav_url = re.sub('(?![a-zA-Z0-9_\.])', '_', nav_url)
        print nav_url

        self.nav_url = nav_url


class Article(ContentItem):
    """Content item for single page articles with their own top-level url."""

    def __init__(self, id=None, title=None, content_body=None, nav_url=None, posted_date=None):
        super(Article, self).__init__(id=id, content_type='article', title=title, content_body=content_body,
                                      posted_date=posted_date)
        super(Article, self).build_nav_url(nav_url)


class BlogItem(ContentItem):
    """Content item for a blog or new entry on the front page."""

    def __init__(self, id=None, title=None, content_body=None, posted_date=None):
        super(BlogItem, self).__init__(id=id, content_type='blog', title=title, content_body=content_body,
                                       posted_date=posted_date)

        # date_nav = self.posted_date. # Build a nice YYYY/mm/dd URL pattern for blogs.
