#
# Copyright (c) 2013 Dorian Pula <dorian.pula@amber-penguin-software.ca>
#
# Rookeries is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# Rookeries is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with Rookeries.  If not, see <http://www.gnu.org/licenses/>.
#
# Please share and enjoy!
#

"""
Views for the journal component.

:copyright: Copyright 2013, Dorian Pula <dorian.pula@amber-penguin-software.ca>
:license: AGPL v3+
"""

import codecs
import os
from flask import safe_join, abort, jsonify
from rookeries.main import rookeries_app


@rookeries_app.route("/api/docs/<page>")
def serve_markdown_page(page="faq"):
    """
    Serving up a page with Markdown content.

    :request page: The name of the page to display.
    """

    # TODO: Remove hardcoding of landing url
    page = "about" if page == "landing" else page

    # TODO: Separate out into URL handler of pages vs. journal entries, and Markdown AJAX calls.

    # Next lets try to use something else like a real file!
    filename = os.path.join(rookeries_app.root_path, safe_join("pages", page + ".md"))

    # Redirect to 404 page.
    if not os.path.exists(filename):
        abort(404)

    with codecs.open(filename, "rb", encoding="utf-8") as f:
        markdown_content = f.read()

    return jsonify({"name": page, "page_content": markdown_content})
