#
# Copyright (c) 2013 Dorian Pula <dorian.pula@amber-penguin-software.ca>
#
# Rookeries is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# Rookeries is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with Rookeries.  If not, see <http://www.gnu.org/licenses/>.
#
# Please share and enjoy!
#

"""
Views related to user management and interaction.

:copyright: Copyright 2013, Dorian Pula <dorian.pula@amber-penguin-software.ca>
:license: AGPL v3+
"""

from flask import redirect, request, session, url_for, g, jsonify
from sqlalchemy.orm.exc import NoResultFound

from rookeries.main import rookeries_app

from rookeries.users import controllers, models
from rookeries.security import authentication as auth

# TODO Add in a common place for creating new users
# TODO Add in a common place for handling check if user logged in.

# TODO Add in a simple FAQ on the project.
# TODO Clean this up massively!


@rookeries_app.route("/login", methods=["POST"])
def login():
    """Login, authentication and request handling."""
    error = None

    # TODO Do via JSON?
    username = request.form["username"]
    password = request.form["password"]

    # TODO Move out controller of logic out of views.
    try:
        user = g.db_session.query(models.User).filter(models.User.username == username).one()
    except NoResultFound:
        user = None

    if user is not None:
        valid_password = auth.check_password(rookeries_app.config, user, password)
        active_user = controllers.check_user_login(rookeries_app.config, user, password)
    else:
        valid_password = False
        active_user = False

    if valid_password and active_user:

        # TODO Use proper authentication tokens instead...
        auth_token = controllers.create_auth_token(g.db_session, user)
        session["auth_token"] = auth_token.token
        session["logged_in"] = True
        session["username"] = user.username

        # TODO Make safe!
        return jsonify(auth_token)

    elif active_user is False:
        error = "User %s has not not been activated yet." % user.username
        return jsonify({"error": error})

    else:
        error = "Invalid username or password."
        return jsonify({"error": error})


@rookeries_app.route('/logout')
def logout():

    # TODO Move out controller of logic out of views.
    username = session.get("username")
    try:
        user = g.db_session.query(models.User).filter(models.User.username == username).one()
    except NoResultFound:
        user = None
    token = session.get("auth_token")
    if user is not None:
        controllers.remove_auth_token(g.db_session, user, token)

    session.pop('user', None)
    session.pop('auth_token', None)
    session.pop('logged_in', None)
    message = 'You were logged out'
    return jsonify({"message": message})


# Handle creation of users and editing of profiles
@rookeries_app.route("/register", methods=["POST"])
def register_user():

    # TODO Consider adding a sign-up key

    # TODO Consider using WTForms for form validation: http://wtforms.simplecodes.com/docs/1.0.4/
    username = request.form["username"]
    password = request.form["password"]
    user_full_name = request.form["user_full_name"]
    email = request.form["email"]

    user = controllers.create_new_user(rookeries_app, g.db_session, email, password, user_full_name, username)

    # TODO Make this more robust and secure...
    # Check if there is a closed invite restriction...

    if rookeries_app.config["USER_REGISTRATION_INVITE_KEY"] is not None:
        invite_key = request.form["invite_key"]
        if invite_key == unicode(rookeries_app.config.USER_REGISTRATION_INVITE_KEY):
            g.db_session.add(user)
            g.db_session.commit()
        else:
            invite_key = request.args.get("invite")
            error = "Invalid invite key (%s) provided." % invite_key

            return jsonify({"error": error})

    else:
        g.db_session.add(user)
        g.db_session.commit()

    return jsonify({"message": "User created successfully."})


# TODO Similair setup for editing the user profile
@rookeries_app.route("/user/<username>")
def display_user_profile(username=None):

    # TODO ... authentication???
    if not session.get("logged_in"):
        return redirect(url_for("register_user"))

    if request.method == "POST":
        username = request.form["username"]
        password = request.form["password"]

        # TODO Do try / catch or deal with exceptions?
        user = g.db_session.query(models.User).filter(models.User.username == username).first()
        hashed_password = controllers.generate_password_hash(rookeries_app.config, user, password)
        user.user_authentication.password = hashed_password

        # TODO Make some checks...
        user.email = request.form["email"]
        user.full_name = request.form["user_full_name"]

        g.db_session.commit()
        return redirect(url_for("display_user_profile", username=user.username))

    else:
        user = g.db_session.query(models.User).filter(models.User.username == username).first()

        # TODO Clean up.
        return jsonify(user)


# TODO Figure out activation and working inside Angular app.
@rookeries_app.route("/activate/<activation_key>")
def activate_user(activation_key=None):

    if not activation_key:
        return "Invalid key {} was specified.".format(activation_key)

    activation = g.db_session.query(models.ActivationKey).filter(models.ActivationKey.key == activation_key).first()
    if not activation:
        return "Invalid key {} was specified.".format(activation_key)

    user = activation.user
    controllers.update_user_state(user, models.UserStatus.active, g.db_session)
    return "User %s is now active and ready to use!" % user.username

# TODO Add in authentication check and fail decorator.
