#
# Copyright (c) 2013 Dorian Pula <dorian.pula@amber-penguin-software.ca>
#
# Rookeries is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# Rookeries is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with Rookeries.  If not, see <http://www.gnu.org/licenses/>.
#
# Please share and enjoy!
#

"""
Module for starting the Rookeries webapp.

:copyright: Copyright 2013, Dorian Pula <dorian.pula@amber-penguin-software.ca>
:license: AGPL v3+
"""
import httplib

import flask
from werkzeug import exceptions


def make_json_app(import_name, **kwargs):
    """Creates a JSON-oriented Flask app.

    All error responses that you don't specifically manage yourself will have a application/json content type, and
    will contain JSON in following format: ::

        { "error": {
                "code": 405,
                "message": "Method Not Allowed"
            }
        }

    Originally Pavel Repin's `snippet receipe for JSON response apps <http://flask.pocoo.org/snippets/83/>`_.


    :param import_name: The name of the app to import.
    """

    def make_json_error(error):
        """
        Make a JSON error response.

        :param error: The error message to turn into JSON.
        """
        error_message = error.name if isinstance(error, exceptions.HTTPException) else str(error)
        error_code = error.code if isinstance(error, exceptions.HTTPException) else httplib.INTERNAL_SERVER_ERROR
        error_json = {"error": {"code": error_code, "message": error_message}}

        response = flask.jsonify(error_json)
        response.status_code = error_code
        return response

    web_app = flask.Flask(import_name, **kwargs)

    for code in iter(exceptions.default_exceptions):
        web_app.error_handler_spec[None][code] = make_json_error

    return web_app
