#
# Copyright (c) 2013-2014 Dorian Pula <dorian.pula@amber-penguin-software.ca>
#
# Rookeries is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# Rookeries is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with Rookeries.  If not, see <http://www.gnu.org/licenses/>.
#
# Please share and enjoy!
#

import fnmatch
import os

import invoke as inv

from . import docs, test


@inv.task
def python():
    """Cleans out all compiled Python bytecode and object files."""
    for root, dirs, files in os.walk(os.curdir):
        for _file in files:
            if fnmatch.fnmatch(_file, '*.pyc'):
                os.remove(os.path.join(root, _file))


@inv.task
def assets():
    """Cleans up after web asset compilation."""
    LESS_PATH = 'rookeries/static/css'
    SCRIPTS_PATH = 'rookeries/static/scripts'
    print('Removing compiled JS files...')
    inv.run('rm -f {source}/*.js'.format(source=SCRIPTS_PATH), echo=True)

    print('Remove compiled CSS files...')
    inv.run('rm -f {source}/*.css'.format(source=LESS_PATH), echo=True)

    print('Remove webassets...')
    inv.run('rm -f rookeries/static/.webassets-cache/*', echo=True)


@inv.task(docs.clean, test.clean, assets, python, name='all')
def clean_all():
    """Cleans up all generated files."""
    print('All clean!')
