#
# Copyright (c) 2013-2014 Dorian Pula <dorian.pula@amber-penguin-software.ca>
#
# Rookeries is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# Rookeries is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with Rookeries.  If not, see <http://www.gnu.org/licenses/>.
#
# Please share and enjoy!
#

import pathlib

import invoke as inv

import rookeries
from . import clean, utils


PACKAGING_STAGING_DIR = 'rookeries_webapp'


@inv.task(name='clean')
def clean_package():
    """Cleans up generated files after packaging the project."""
    utils.delete_in_path_list([app_package_name(), PACKAGING_STAGING_DIR])


@inv.task(clean_package, clean.python, clean.assets)
def package():
    """Prepares the project for packaging."""
    packaging_dir = pathlib.Path(PACKAGING_STAGING_DIR)
    if not packaging_dir.exists():
        packaging_dir.mkdir()
    inv.run('ln -s ../rookeries {}/rookeries'.format(PACKAGING_STAGING_DIR))
    inv.run('ln -s ../requirements.txt {}/requirements.txt'.format(PACKAGING_STAGING_DIR))
    inv.run('ln -s ../package.json {}/package.json'.format(PACKAGING_STAGING_DIR))

    inv.run('tar zcvhf {} {}'.format(app_package_name(), PACKAGING_STAGING_DIR), echo=True)


def app_package_name(pkg_format='tar.bz2'):
    """
    Gets the name of the app package that will get generated as part of this deployment.

    :param pkg_format: The format of the package.  By default this the package will be a BZip tarball.
    :return: The name of the app package
    """
    pkg_filename = '{name}-{version}.{pkg_format}'
    return pkg_filename.format(name=rookeries.__name__, version=rookeries.__version__, pkg_format=pkg_format)
