# coding=utf-8
#
# Copyright (c) 2013-2014 Dorian Pula <dorian.pula@amber-penguin-software.ca>
#
# Rookeries is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# Rookeries is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with Rookeries.  If not, see <http://www.gnu.org/licenses/>.
#
# Please share and enjoy!
#

import invoke as inv

from . import utils


NOSE_OPTIONS_TEMPLATE = ('nosetests {path} --with-coverage --cover-html --cover-inclusive --cover-package={pkg} '
                         '--cover-branches')


@inv.task
def clean():
    """Cleans test reports and artifacts."""
    test_folders = ['cover', '.tox']
    utils.delete_in_path_list(test_folders)


@inv.task
def style():
    """Test the coding style using Flake8."""
    inv.run('flake8', echo=True)


@inv.task
def server():
    """Test the server webapp using both unit and integration tests."""
    nose_command = NOSE_OPTIONS_TEMPLATE.format(path='tests/server', pkg='rookeries')
    inv.run(nose_command, echo=True)


@inv.task
def tasks():
    """Test the bundled tasks for working with rookeries."""
    nose_command = NOSE_OPTIONS_TEMPLATE.format(path='tests/tasks', pkg='tasks')
    inv.run(nose_command, echo=True)


@inv.task(clean, server, tasks, style, name='all')
def test_all():
    print(u'Everything looks good! ☻')
