#
# Copyright (c) 2013-2014 Dorian Pula <dorian.pula@amber-penguin-software.ca>
#
# Rookeries is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# Rookeries is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with Rookeries.  If not, see <http://www.gnu.org/licenses/>.
#
# Please share and enjoy!
#

"""Utility and helper functions for the packaged tasks."""

import os
import pathlib
import shutil


def delete_in_path_list(path_list, dry_run=False):
    """
    Deletes all the elements in the given path list.

    :param dry_run: Mode for switching between a dry run and actual deletion run.
    """
    if dry_run:
        print('Running in: Dry run mode.')

    for folder in path_list:
        path = pathlib.Path(folder)
        if not path.exists():
            continue
        print('Deleting... {}'.format(path))

        if not dry_run and path.is_dir():
            shutil.rmtree(path.as_posix())
            continue

        if not dry_run:
            path.unlink()


class cd(object):
    """Context manager to change a current working directory."""

    def __init__(self, new_path):
        self.new_path = new_path
        self.previous_path = os.getcwd()

    def __enter__(self):
        os.chdir(self.new_path)

    def __exit__(self, etype, value, traceback):
        os.chdir(self.previous_path)
