#
# Copyright (c) 2013-2014 Dorian Pula <dorian.pula@amber-penguin-software.ca>
#
# Rookeries is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# Rookeries is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with Rookeries.  If not, see <http://www.gnu.org/licenses/>.
#
# Please share and enjoy!
#

import invoke as inv

from . import deploy, utils


@inv.task
def start():
    """Start the Vagrant box."""
    with utils.cd('vagrant'):
        inv.run('vagrant up', echo=True, pty=True)


@inv.task
def stop():
    """Stop the Vagrant box."""
    with utils.cd('vagrant'):
        inv.run('vagrant halt', echo=True, pty=True)


@inv.task(deploy.package, start)
def install(verbose=0):
    """Provision the vagrant box and deploy the Rookeries on the box."""
    install_ansible_roles()
    run_ansible_vagrant_playbook('playbooks/provision.yaml', verbose)


def generate_verbosity_tag(verbosity=0):
    if verbosity < 1:
        return ''
    return '-{}'.format('v' * min(verbosity, 4))


def run_ansible_vagrant_playbook(playbook, verbose):
    options = generate_verbosity_tag(verbose)
    ansible_cmd = 'ansible-playbook-vagrant {playbook} {extra_opts}'.format(playbook=playbook, extra_opts=options)

    with utils.cd('vagrant'):
        inv.run('rm -rf hosts_vagrant', echo=True)
        inv.run(ansible_cmd, echo=True, pty=True)


def install_ansible_roles():
    ANSIBLE_ROLE_PATH = '--roles-path=playbooks/extern_roles/'
    ANSIBLE_ROOKERIES_SCM = 'git+https://bitbucket.org/dorianpula/ansible-rookeries'

    with utils.cd('vagrant'):
        listing_result = inv.run('ansible-galaxy list {}'.format(ANSIBLE_ROLE_PATH))
        if 'ansible-rookeries' not in listing_result.stdout:
            inv.run('ansible-galaxy install {} {}'.format(ANSIBLE_ROLE_PATH, ANSIBLE_ROOKERIES_SCM))
