import unittest

import mock
from nose import tools as asserts

from rookeries.users import models
from rookeries.security import authentication

# TODO Separate hashing of something from the building of the hashable string.

# TODO Change API to taken in hash rather than config object.


class CheckPasswordTests(unittest.TestCase):

    GENERATE_PASSWORD_QUALIFIED_NAME = 'rookeries.security.authentication.generate_password_hash'

    def setUp(self):
        self.test_password_salt = 'salt'
        self.test_username = 'test_user'
        self.test_password = 'password'
        self.test_expected_password_hash = 'password_hash'
        self.test_user = mock.Mock(spec=models.User, username=self.test_username)
        self.test_user.user_authentication.password = self.test_expected_password_hash

    @mock.patch(GENERATE_PASSWORD_QUALIFIED_NAME, autospec=True)
    def test_check_password_returns_false_when_empty_user_passed_in(self, mock_generate_password):
        self.test_user = None
        asserts.eq_(False, authentication.check_password(self.test_password_salt, self.test_user, self.test_password))

    @mock.patch(GENERATE_PASSWORD_QUALIFIED_NAME, autospec=True)
    def test_check_password_returns_false_if_generated_hash_does_not_match_actual_hash(self, mock_generate_password):
        test_actual_hash = 'different_hash'
        mock_generate_password.return_value = test_actual_hash
        asserts.assert_not_equal(self.test_expected_password_hash, test_actual_hash)
        asserts.eq_(False, authentication.check_password(self.test_password_salt, self.test_user, self.test_password))

    @mock.patch(GENERATE_PASSWORD_QUALIFIED_NAME, autospec=True)
    def test_check_password_returns_true_if_generated_hash_matches_actual_hash(self, mock_generate_password):
        test_actual_hash = self.test_expected_password_hash
        mock_generate_password.return_value = self.test_expected_password_hash
        asserts.eq_(self.test_expected_password_hash, test_actual_hash)
        asserts.eq_(True, authentication.check_password(self.test_password_salt, self.test_user, self.test_password))
